@@ -161,6 +161,13 @@ class Review(object):
             return None
         return st
 
+    def _extract_file(self, rel):
+        '''Extract file'''
+        fn = os.path.join(self.unpack_dir, rel)
+        if not os.path.isfile(fn):
+            error("Could not find '%s'" % rel)
+        return open_file_read(fn)
+
     def _path_join(self, dirname, rest):
         return os.path.join(dirname, rest)
 
@@ -654,6 +661,7 @@ def find_external_symlinks(unpack_dir, pkg_files):
                   'libdl',
                   'libmemusage',
                   'libm',
+                  'libmvec',
                   'libnsl',
                   'libnss_compat',
                   'libnss_dns',
@@ -673,7 +681,7 @@ def find_external_symlinks(unpack_dir, pkg_files):
     for lib in libc6_libs:
         libc6_pats.append(re.compile(r'%s%s' % (lib, common)))
     libc6_pats.append(re.compile(r'ld-*.so$'))
-    libc6_pats.append(re.compile(r'ld-linux-*.so\.[0-9.]+$'))
+    libc6_pats.append(re.compile(r'ld-linux-.*.so\.[0-9.]+$'))
 
     def _in_patterns(pats, f):
         for pat in pats:
