@@ -20,7 +20,7 @@ import re
 import yaml
 
 
-from clickreviews.common import(
+from clickreviews.common import (
     Review,
     ReviewException,
     error,
@@ -93,10 +93,12 @@ class SnapReview(Review):
     # merge this into self.interfaces after reading
     # apparmor-easyprof-ubuntu.json
     interfaces_attribs = {'bool-file': {'path/slots': ""},
-                          'content': {'read/slots': "",
-                                      'write/slots': "",
+                          'browser-support': {'allow-sandbox/plugs': False},
+                          'content': {'read/slots': [],
+                                      'write/slots': [],
                                       'target/plugs': "",
                                       },
+                          'gpio': {'number/slots': 0},
                           'serial-port': {'path/slots': ""},
                           }
 
